/****************************************************************************
** Meta object code from reading C++ file 'dirmodelutils.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../xdg-desktop-portal-kde-6.7.0/src/kirigami-filepicker/declarative/dirmodelutils.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dirmodelutils.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13DirModelUtilsE_t {};
} // unnamed namespace

template <> constexpr inline auto DirModelUtils::qt_create_metaobjectdata<qt_meta_tag_ZN13DirModelUtilsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DirModelUtils",
        "homePathChanged",
        "",
        "getUrlParts",
        "QUrl",
        "url",
        "partialUrlForIndex",
        "index",
        "directoryOfUrl",
        "path",
        "fileNameOfUrl",
        "mkdir"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'homePathChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'getUrlParts'
        QtMocHelpers::MethodData<QStringList(const QUrl &) const>(3, 2, QMC::AccessPublic, QMetaType::QStringList, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Method 'partialUrlForIndex'
        QtMocHelpers::MethodData<QUrl(QUrl, int) const>(6, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { 0x80000000 | 4, 5 }, { QMetaType::Int, 7 },
        }}),
        // Method 'directoryOfUrl'
        QtMocHelpers::MethodData<QUrl(const QString &) const>(8, 2, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::QString, 9 },
        }}),
        // Method 'fileNameOfUrl'
        QtMocHelpers::MethodData<QString(const QString &) const>(10, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 9 },
        }}),
        // Method 'mkdir'
        QtMocHelpers::MethodData<void(const QUrl) const>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DirModelUtils, qt_meta_tag_ZN13DirModelUtilsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DirModelUtils::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DirModelUtilsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DirModelUtilsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13DirModelUtilsE_t>.metaTypes,
    nullptr
} };

void DirModelUtils::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DirModelUtils *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->homePathChanged(); break;
        case 1: { QStringList _r = _t->getUrlParts((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 2: { QUrl _r = _t->partialUrlForIndex((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 3: { QUrl _r = _t->directoryOfUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 4: { QString _r = _t->fileNameOfUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->mkdir((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DirModelUtils::*)()>(_a, &DirModelUtils::homePathChanged, 0))
            return;
    }
}

const QMetaObject *DirModelUtils::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DirModelUtils::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13DirModelUtilsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DirModelUtils::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void DirModelUtils::homePathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
