/****************************************************************************
** Meta object code from reading C++ file 'screencast.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../xdg-desktop-portal-kde-6.7.0/src/screencast.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'screencast.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16ScreenCastPortalE_t {};
} // unnamed namespace

template <> constexpr inline auto ScreenCastPortal::qt_create_metaobjectdata<qt_meta_tag_ZN16ScreenCastPortalE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScreenCastPortal",
        "D-Bus Interface",
        "org.freedesktop.impl.portal.ScreenCast",
        "CreateSession",
        "",
        "QDBusObjectPath",
        "handle",
        "session_handle",
        "app_id",
        "QVariantMap",
        "options",
        "QVariantMap&",
        "results",
        "SelectSources",
        "Start",
        "parent_window",
        "QDBusMessage",
        "message",
        "uint&",
        "replyResponse",
        "replyResults",
        "version",
        "AvailableSourceTypes",
        "AvailableCursorModes",
        "SourceType",
        "Any",
        "Monitor",
        "Window",
        "Virtual",
        "CursorModes",
        "Hidden",
        "Embedded",
        "Metadata",
        "PersistMode",
        "NoPersist",
        "PersistWhileRunning",
        "PersistUntilRevoked"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'CreateSession'
        QtMocHelpers::SlotData<uint(const QDBusObjectPath &, const QDBusObjectPath &, const QString &, const QVariantMap &, QVariantMap &)>(3, 4, QMC::AccessPublic, QMetaType::UInt, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 5, 7 }, { QMetaType::QString, 8 }, { 0x80000000 | 9, 10 },
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'SelectSources'
        QtMocHelpers::SlotData<uint(const QDBusObjectPath &, const QDBusObjectPath &, const QString &, const QVariantMap &, QVariantMap &)>(13, 4, QMC::AccessPublic, QMetaType::UInt, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 5, 7 }, { QMetaType::QString, 8 }, { 0x80000000 | 9, 10 },
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'Start'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &, const QDBusObjectPath &, const QString &, const QString &, const QVariantMap &, const QDBusMessage &, uint &, QVariantMap &)>(14, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 5, 7 }, { QMetaType::QString, 8 }, { QMetaType::QString, 15 },
            { 0x80000000 | 9, 10 }, { 0x80000000 | 16, 17 }, { 0x80000000 | 18, 19 }, { 0x80000000 | 11, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'version'
        QtMocHelpers::PropertyData<uint>(21, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'AvailableSourceTypes'
        QtMocHelpers::PropertyData<uint>(22, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'AvailableCursorModes'
        QtMocHelpers::PropertyData<uint>(23, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'SourceType'
        QtMocHelpers::EnumData<enum SourceType>(24, 24, QMC::EnumFlags{}).add({
            {   25, SourceType::Any },
            {   26, SourceType::Monitor },
            {   27, SourceType::Window },
            {   28, SourceType::Virtual },
        }),
        // enum 'CursorModes'
        QtMocHelpers::EnumData<enum CursorModes>(29, 29, QMC::EnumFlags{}).add({
            {   30, CursorModes::Hidden },
            {   31, CursorModes::Embedded },
            {   32, CursorModes::Metadata },
        }),
        // enum 'PersistMode'
        QtMocHelpers::EnumData<enum PersistMode>(33, 33, QMC::EnumFlags{}).add({
            {   34, PersistMode::NoPersist },
            {   35, PersistMode::PersistWhileRunning },
            {   36, PersistMode::PersistUntilRevoked },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ScreenCastPortal, qt_meta_tag_ZN16ScreenCastPortalE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ScreenCastPortal::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ScreenCastPortalE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ScreenCastPortalE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16ScreenCastPortalE_t>.metaTypes,
    nullptr
} };

void ScreenCastPortal::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScreenCastPortal *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { uint _r = _t->CreateSession((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariantMap&>>(_a[5])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 1: { uint _r = _t->SelectSources((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariantMap&>>(_a[5])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->Start((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QDBusMessage>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<uint&>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<QVariantMap&>>(_a[8]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 5:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusMessage >(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uint*>(_v) = _t->version(); break;
        case 1: *reinterpret_cast<uint*>(_v) = _t->AvailableSourceTypes(); break;
        case 2: *reinterpret_cast<uint*>(_v) = _t->AvailableCursorModes(); break;
        default: break;
        }
    }
}

const QMetaObject *ScreenCastPortal::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScreenCastPortal::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ScreenCastPortalE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int ScreenCastPortal::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN17ScreenCastSessionE_t {};
} // unnamed namespace

template <> constexpr inline auto ScreenCastSession::qt_create_metaobjectdata<qt_meta_tag_ZN17ScreenCastSessionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScreenCastSession"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ScreenCastSession, qt_meta_tag_ZN17ScreenCastSessionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ScreenCastSession::staticMetaObject = { {
    QMetaObject::SuperData::link<Session::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ScreenCastSessionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ScreenCastSessionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17ScreenCastSessionE_t>.metaTypes,
    nullptr
} };

void ScreenCastSession::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScreenCastSession *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ScreenCastSession::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScreenCastSession::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ScreenCastSessionE_t>.strings))
        return static_cast<void*>(this);
    return Session::qt_metacast(_clname);
}

int ScreenCastSession::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Session::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
